@@ -88,7 +88,11 @@
 #' @name rna_quality_control
 #' @importFrom beachmat initializeCpp tatami.dim
 computeRnaQcMetrics <- function(x, subsets, num.threads = 1) {
-    stopifnot(length(subsets) == 0 || !is.null(names(subsets)))
+    if (length(subsets) > 0 && is.null(names(subsets))) {
+        stop("subsets should be a named list")
+    }
+    .checkSEX(x, "quickRnaQc.se")
+
     ptr <- initializeCpp(x, .check.na=FALSE)
 
     subsets <- as.list(subsets)
