@@ -1,6 +1,5 @@
-//#include "config.h"
+#include "config.h"
 
-#include "Rcpp.h"
 #include "scran_norm/scran_norm.hpp"
 
 //[[Rcpp::export(rng=false)]]
@@ -9,5 +8,5 @@ double choose_pseudo_count(Rcpp::NumericVector size_factors, double quantile, do
     opt.quantile = quantile;
     opt.max_bias = max_bias;
     opt.min_value = min_value;
-    return scran_norm::choose_pseudo_count(size_factors.size(), static_cast<const double*>(size_factors.begin()), opt);
+    return scran_norm::choose_pseudo_count(sanisizer::cast<std::size_t>(size_factors.size()), static_cast<const double*>(size_factors.begin()), opt);
 }
