@@ -12,18 +12,27 @@ test_that("quickAdtQc.se works as expected", {
     expect_type(metadata(out)$qc$thresholds, "list")
 
     out <- quickAdtQc.se(se, subsets=list(igg=1:5))
-    expect_type(out$igg.sum, "double")
+    expect_type(out$subset.sum.igg, "double")
 
     out2 <- quickAdtQc.se(se, subsets=list(igg=1:5), output.prefix="WHEE.")
     expect_identical(out2$WHEE.sum, out$sum)
     expect_identical(out2$WHEE.detected, out$detected)
-    expect_identical(out2$WHEE.igg.sum, out$igg.sum)
+    expect_identical(out2$WHEE.subset.sum.igg, out$subset.sum.igg)
     expect_identical(out2$WHEE.keep, out$keep)
 
     out3 <- quickAdtQc.se(se, subsets=list(igg=1:5, bar=6:10), flatten=FALSE)
-    expect_identical(out$igg.sum, out3$sum$igg)
-    expect_type(out3$sum$bar, "double")
+    expect_identical(out$subset.sum.igg, out3$subset.sum$igg)
+    expect_type(out3$subset.sum$bar, "double")
 
     out4 <- quickAdtQc.se(se, subsets=list(), meta.name=NULL)
     expect_null(metadata(out4)$qc)
 })
+
+test_that("quickRnaQc.se works with custom thresholds", {
+    fixed <- list(sum=1, detected=1)
+    out <- quickAdtQc.se(se, subsets=list(), thresholds=fixed)
+
+    refixed <- fixed
+    refixed$subset.sum <- setNames(numeric(0), character(0))
+    expect_identical(metadata(out)$qc$thresholds, refixed)
+})
